#!/bin/sh
#expects to have original SVN directories ptlib-svn, opal-svn and ekiga-svn
# and changelog inside

#this can me done with:
# svn co https://opalvoip.svn.sourceforge.net/svnroot/opalvoip/ptlib/trunk ptlib-svn
# svn co https://opalvoip.svn.sourceforge.net/svnroot/opalvoip/opal/trunk opal-svn
# svn co http://svn.gnome.org/svn/ekiga/trunk ekiga-svn
# for i in ptlib opal ekiga; do cd $i-svn; svn2cl -o changelog; cd ..; done

#check directories
if [ ! -e ptlib-svn -o ! -e opal-svn -o ! -e ekiga-svn ]; then
	echo "Please do a fresh installation in *-svn directories: svn co"
	exit 1
fi

if [ -e ptlib -o -e opal -o -e ekiga ]; then
	echo "Error: ptlib/opal/ekiga directories found, remove them.  Aborting."
	exit 2
fi

#svn update, populate with debian/ and check patches
for i in ptlib opal ekiga; do
	echo -n "==== Processing $i..."; date
	cd $i-svn
	echo "svn up"
	REVOLD=`svn info|sed -ne '/^Rev/s,^.* ,,p'`
	svn up
	REVNEW=`svn info|sed -ne '/^Rev/s,^.* ,,p'`
	echo "Updating changelog..."
	if [ $REVOLD -eq $REVNEW ]; then
		echo "There was no SVN update, so no new entries in changelog"
	else
		#don't use ekiga own changelog, because it has three separate changelog
		svn2cl -r $REVNEW:`expr $REVOLD + 1` -o changelog-old-tmp
		less changelog-old-tmp
		# sometimes there is no record even if revisions are different
		if [ `cat changelog-old-tmp | wc -l` -le 2 ]; then
			echo "changelog is not empty, but since it does not contain any record, I remove it."
			rm changelog-old-tmp
		fi
		cat changelog >>changelog-old-tmp
		mv -f changelog-old-tmp changelog
	fi
	cd ..
	cp -a $i-svn $i
	cd $i
	echo "Patching with debian files..."
	patch -p1 <../$i.diff >/dev/null
	chmod a+x debian/rules  # needed by dpatch-edit-patch
	for j in debian/patches/*dpatch; do
		echo "== dry-run $j"
		patch -p1 --dry-run <$j
	done
	cd ..
done
echo -e "\aDo the patches apply cleanly? (ctrl-c to stop)"
read

#build
date=`date "+%Y%m%d"`
for i in ptlib opal ekiga; do
	echo -n "Processing $i, please wait... "; date
	cd $i
	echo "Exporting the svn repository + changelog..."
	svn export . ../$i.orig
	cp -a changelog ../$i.orig
	echo "Updating the date in debian files..."
	sed -i "s/20080418/$date/g" debian/changelog
	sed -i "s/Sun, 18 Apr 2008 00:00:00 +0200/`date -R`/g" debian/changelog
	sed -i "s/20080418/$date/g" debian/control
	if [ $i = "ekiga" ]; then sed -i "s/20080418/$date/g" debian/menu; fi

	if [ $i = "ptlib" ]; then
		while dpkg -l|grep libpt-snapshot >/dev/null; do echo -e "\aUninstalling libpt-snapshot\*, libopal-snapshot\* and ekiga-snapshot\*, enter root password to su."; su -c "dpkg -P libpt-snapshot libpt-snapshot-plugins-alsa libpt-snapshot-plugins-v4l2 libpt-snapshot-dev libopal-snapshot libopal-snapshot-dev ekiga-snapshot ekiga-snapshot-gtkonly" ; done
	elif [ $i = "opal" ]; then
		echo -e "\aInstalling the newly built libpt packages, enter root password to su."
		while ! su -c "dpkg -i ../libpt-snapshot_*.deb ../libpt-snapshot-dev_*.deb"; do sleep 1; done
	elif [ $i = "ekiga" ]; then
		echo -e "\aInstalling the newly built opal packages, enter root password to su."
		while ! su -c "dpkg -i ../libopal-snapshot_*.deb ../libopal-snapshot-dev_*.deb"; do sleep 1; done
	fi
	echo "Building $i packages, please wait..."
	debuild >/dev/null
	if [ $? -ne 0 ]; then
		echo "debuild returned value is not zero, it seems something was broken, continue? (ctrl-c to stop)"
		read
	fi
	cd ..
done

date

#execute ekiga-snapshot
echo -e "\aInstalling the new ekiga package, enter root password to su."
while ! su -c "dpkg -i ekiga-snapshot_*.deb libpt-snapshot-plugins-v4l2_*.deb libpt-snapshot-plugins-alsa_*.deb"; do sleep 1; done
ekiga

#update Web site
echo -ne "\aMove files to dsiff98 directory? (ctrl-c to quit)"
read
echo "Removing old files..."
rm ~/misc/dsiff98/ekiga/*snapshot*
echo "Moving new files inside..."
mv -v *snapshot* ~/misc/dsiff98/ekiga
echo "Uploading to internet..."
cd ~/misc/dsiff98
./mirror.lftp

# send mail
echo "Don't forget to send mail"
echo "Don't forget to remove ptlib opal ekiga directories"